@@ -22,6 +22,9 @@ Main program of ibus-typing-booster
 '''
 from typing import Any
 from typing import Union
+from typing import Type
+from typing import Optional
+import types
 import os
 import sys
 import argparse
@@ -33,6 +36,8 @@ from signal import signal, SIGTERM, SIGINT
 from gi import require_version # type: ignore
 require_version('IBus', '1.0')
 from gi.repository import IBus # type: ignore
+require_version('Gio', '2.0')
+from gi.repository import Gio
 require_version('GLib', '2.0')
 from gi.repository import GLib
 # pylint: enable=wrong-import-position
@@ -42,6 +47,22 @@ import itb_version
 
 LOGGER = logging.getLogger('ibus-typing-booster')
 
+def log_unhandled_exception(
+    exc_type: Type[BaseException],
+    exc_value: BaseException,
+    exc_traceback: Optional[types.TracebackType]
+) -> None:
+    '''Log any unhandled exception.'''
+    if issubclass(exc_type, KeyboardInterrupt):
+        sys.__excepthook__(exc_type, exc_value, exc_traceback)
+        return
+    LOGGER.error(
+        'Unhandled exception',
+        exc_info=(exc_type, exc_value, exc_traceback)
+    )
+
+sys.excepthook = log_unhandled_exception
+
 DEBUG_LEVEL = int(0)
 try:
     DEBUG_LEVEL = int(str(os.getenv('IBUS_TYPING_BOOSTER_DEBUG_LEVEL')))
@@ -359,12 +380,21 @@ def write_xml() -> None:
         icon = os.path.join(ICON_DIR, 'ibus-typing-booster.svg')
         description = 'A completion input method to speedup typing.'
         symbol = '🚀'
+        if (itb_util.is_desktop('gnome')
+            and itb_util.get_gnome_shell_version() >= (48, 3)):
+            # If running on Gnome and gnome-shell is new enough to contain
+            # https://gitlab.gnome.org/GNOME/gnome-shell/-/merge_requests/3753
+            # make the symbol black and white:
+            symbol = '🚀\uFE0E'
         setup = SETUP_TOOL
         icon_prop_key = 'InputMode'
         rank = 0
+        schema_path = '/org/freedesktop/ibus/engine/typing-booster/'
         if ime != 'typing-booster':
             m17n_lang, m17n_name = ime.split('-', maxsplit=1)
             name = f'tb:{m17n_lang}:{m17n_name}'
+            schema_path = ('/org/freedesktop/ibus/engine/tb/'
+                           f'{m17n_lang}/{m17n_name}/')
             rank = 0
             for pattern, pattern_rank in rank_patterns:
                 if re.fullmatch(pattern, name):
@@ -391,6 +421,13 @@ def write_xml() -> None:
             icon =  m17n_db_info.get_icon(ime)
             description = m17n_db_info.get_description(ime)
             setup = SETUP_TOOL + f' --engine-name {name}'
+        gsettings = Gio.Settings(
+            schema='org.freedesktop.ibus.engine.typing-booster',
+            path=schema_path)
+        user_symbol = itb_util.variant_to_value(
+            gsettings.get_user_value('inputmodetruesymbol'))
+        if user_symbol is not None:
+            symbol = user_symbol
 
         _name = SubElement(_engine, 'name')
         _name.text = name
@@ -463,7 +500,6 @@ def main() -> None:
     LOGGER.addHandler(log_handler)
     LOGGER.info('********** STARTING **********')
 
-    IBus.init()
     if _ARGS.daemon:
         if os.fork():
             sys.exit()
