@@ -27,8 +27,11 @@ import logging
 import unittest
 import unicodedata
 
+# pylint: disable=wrong-import-position
 from gi import require_version # type: ignore
 require_version('IBus', '1.0')
+from gi.repository import IBus # type: ignore
+# pylint: enable=wrong-import-position
 
 LOGGER = logging.getLogger('ibus-typing-booster')
 
@@ -176,6 +179,70 @@ class ItbUtilTestCase(unittest.TestCase):
                     keep=unicodedata.normalize('NFD', 'åÅÖö'))),
             'alkoholförgiftning')
 
+    def test_msymbol_for_return_and_escape(self) -> None:
+        '''
+        Return: https://github.com/mike-fabian/ibus-typing-booster/issues/457
+        Escape: https://github.com/mike-fabian/ibus-typing-booster/issues/704
+        '''
+        key_event = itb_util.KeyEvent(
+            IBus.KEY_Escape,
+            0,
+            0)
+        self.assertEqual(key_event.msymbol, 'Escape')
+        key_event = itb_util.KeyEvent(
+            IBus.KEY_Escape,
+            0,
+            IBus.ModifierType.SHIFT_MASK)
+        self.assertEqual(key_event.msymbol, 'S-Escape')
+        key_event = itb_util.KeyEvent(
+            IBus.KEY_Escape,
+            0,
+            IBus.ModifierType.CONTROL_MASK)
+        self.assertEqual(key_event.msymbol, 'C-Escape')
+        key_event = itb_util.KeyEvent(
+            IBus.KEY_Escape,
+            0,
+            IBus.ModifierType.SHIFT_MASK | IBus.ModifierType.CONTROL_MASK)
+        self.assertEqual(key_event.msymbol, 'S-C-Escape')
+        key_event = itb_util.KeyEvent(
+            IBus.KEY_Return,
+            0,
+            0)
+        self.assertEqual(key_event.msymbol, 'Return')
+        key_event = itb_util.KeyEvent(
+            IBus.KEY_Return,
+            0,
+            IBus.ModifierType.SHIFT_MASK)
+        self.assertEqual(key_event.msymbol, 'S-Return')
+        key_event = itb_util.KeyEvent(
+            IBus.KEY_Return,
+            0,
+            IBus.ModifierType.CONTROL_MASK)
+        self.assertEqual(key_event.msymbol, 'C-Return')
+        key_event = itb_util.KeyEvent(
+            IBus.KEY_Return,
+            0,
+            IBus.ModifierType.SHIFT_MASK | IBus.ModifierType.CONTROL_MASK)
+        self.assertEqual(key_event.msymbol, 'S-C-Return')
+
+    def test_msymbol_for_tab_backspace_delete(self) -> None:
+        ''' https://github.com/mike-fabian/ibus-typing-booster/issues/709 '''
+        key_event = itb_util.KeyEvent(
+            IBus.KEY_Tab,
+            0,
+            0)
+        self.assertEqual(key_event.msymbol, 'Tab')
+        key_event = itb_util.KeyEvent(
+            IBus.KEY_BackSpace,
+            0,
+            0)
+        self.assertEqual(key_event.msymbol, 'BackSpace')
+        key_event = itb_util.KeyEvent(
+            IBus.KEY_Delete,
+            0,
+            0)
+        self.assertEqual(key_event.msymbol, 'Delete')
+
 if __name__ == '__main__':
     LOG_HANDLER = logging.StreamHandler(stream=sys.stderr)
     LOGGER.setLevel(logging.DEBUG)
